@@ -145,7 +145,10 @@ class CensorKeyword(object):
                         continue
                     for matched_i in matched:
                         match_keys.add(matched_i)
-                match_keys.add(k)
+                
+                for w in self.group_keyword[k]:
+                    match_keys.add(w)
+                
                 #返回最小的那个 事前比事后优先级高
                 cat_id = self.group_id_to_cat_id[k]
                 if cat_id < group:
